var group__PkgShapeDetectionRGOnPoints =
[
    [ "CGAL::Shape_detection::Point_set::K_neighbor_query< GeomTraits, Item_, PointMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1K__neighbor__query.html", [
      [ "Item", "classCGAL_1_1Shape__detection_1_1Point__set_1_1K__neighbor__query.html#a26cd48b9151b52fbe619e633dfe38ca4", null ],
      [ "K_neighbor_query", "classCGAL_1_1Shape__detection_1_1Point__set_1_1K__neighbor__query.html#a17e0734d4676ed70b421fb235c709e9c", null ],
      [ "operator()", "classCGAL_1_1Shape__detection_1_1Point__set_1_1K__neighbor__query.html#a5fa6a043df72b880ce11eb855c890c8b", null ],
      [ "K_neighbor_query_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#ga2b48bc9aeb7b6413813dde2e245d052c", null ],
      [ "make_k_neighbor_query", "group__PkgShapeDetectionRGOnPointSet3.html#ga52be33ec5ef09a073c754000e03f174a", null ]
    ] ],
    [ "CGAL::Shape_detection::Point_set::Least_squares_circle_fit_region< GeomTraits, Item_, PointMap, NormalMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__region.html", [
      [ "FT", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__region.html#a0ed55d0f5e2ebb6874fcb61e33259184", null ],
      [ "Item", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__region.html#a46a11681f1a9f33d3f2c3f0da6689a57", null ],
      [ "Primitive", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__region.html#a00557b9108417f5ba0300e74a9ccb4d4", null ],
      [ "Region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__region.html#aa31c4bd76e0aaa8257f84176db28844d", null ],
      [ "Region_unordered_map", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__region.html#ad0fef4e18cdf37814c51ad578a46bd6c", null ],
      [ "Least_squares_circle_fit_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__region.html#a7ac0d1b4875b60296882af5b40fae04d", null ],
      [ "is_part_of_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__region.html#a453e82ff0fd05599590a5d5e789a5ec7", null ],
      [ "is_valid_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__region.html#a012a659086f3a5d21abf7dfd7b655f1f", null ],
      [ "primitive", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__region.html#a812b85d203ad1af6dcaa823cf6395982", null ],
      [ "region_index_map", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__region.html#ae48aa27239ad686fbbd95a4a7bf3d778", null ],
      [ "update", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__region.html#a109aae0d5758b0383e30941fdd944080", null ],
      [ "Least_squares_circle_fit_region_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#gafa9c8cff6daec11f0cc566eea224b0cb", null ],
      [ "make_least_squares_circle_fit_region", "group__PkgShapeDetectionRGOnPointSet3.html#ga98028376532032ce39ca73ec0d0a4290", null ]
    ] ],
    [ "CGAL::Shape_detection::Point_set::Least_squares_circle_fit_sorting< GeomTraits, Item_, NeighborQuery, PointMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__sorting.html", [
      [ "Item", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__sorting.html#a6095b9c4275c14fcef743d0e991cfefb", null ],
      [ "Seed_range", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__sorting.html#ab5b44994291d13f23752728ff4ceef30", null ],
      [ "Least_squares_circle_fit_sorting", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__sorting.html#a5a079901165ff2a42712f474c4b639f5", null ],
      [ "ordered", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__sorting.html#af75b39a1ef8447fe491a44b9bccaec79", null ],
      [ "sort", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__circle__fit__sorting.html#abd84b445d561a7cb592a9e53fcca7d4d", null ],
      [ "Least_squares_circle_fit_sorting_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#gafae4edae3495cf66916896ef85edcca7", null ],
      [ "make_least_squares_circle_fit_sorting", "group__PkgShapeDetectionRGOnPointSet3.html#gae5721053042d8520f34ab84b4d0a58d0", null ]
    ] ],
    [ "CGAL::Shape_detection::Point_set::Least_squares_cylinder_fit_region< GeomTraits, Item_, PointMap, NormalMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__region.html", [
      [ "FT", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__region.html#a243df34ea1d7316f776911df5172d33d", null ],
      [ "Item", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__region.html#a8618c72d86e3d92040735fe0ea0d357f", null ],
      [ "Primitive", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__region.html#a6b9223dcc2bf74bf0f39f921df7b5abc", null ],
      [ "Region_unordered_map", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__region.html#ab6292c1d20a5dfba34e19fed405656e0", null ],
      [ "Least_squares_cylinder_fit_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__region.html#a88a11a31ebb29e39ab87b680a3ab1f9d", null ],
      [ "is_part_of_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__region.html#a1d371f9fbf935a215d9ad24dd1644c3e", null ],
      [ "is_valid_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__region.html#a0ec5ed0d37f1a47dc0f088fed99b15ff", null ],
      [ "primitive", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__region.html#ac171ae04cad6b2575aee1790673ab336", null ],
      [ "region_index_map", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__region.html#a1787b992a1ef556dc4347daa2c072095", null ],
      [ "update", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__region.html#ad1534aee55abe8009e1c630d3df36454", null ],
      [ "Least_squares_cylinder_fit_region_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#gafedf1b817adb77fbcb5f84e9e3e79d0b", null ],
      [ "make_least_squares_cylinder_fit_region", "group__PkgShapeDetectionRGOnPointSet3.html#ga99a5a954bbbee8caa18069dd81de0103", null ]
    ] ],
    [ "CGAL::Shape_detection::Point_set::Least_squares_cylinder_fit_sorting< GeomTraits, Item_, NeighborQuery, PointMap, NormalMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__sorting.html", [
      [ "Item", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__sorting.html#ae97081601396871c1726bd229e18ad06", null ],
      [ "Seed_range", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__sorting.html#aec2c1a908dc3b3e09474b92454e949ad", null ],
      [ "Least_squares_cylinder_fit_sorting", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__sorting.html#acf8cde3d367ac82dfb42a7586db806a4", null ],
      [ "ordered", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__sorting.html#a37e2f7d79ea0f2336d4a0ab3dc5f1dfb", null ],
      [ "sort", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__cylinder__fit__sorting.html#a2e26d6a510df50abe8c633375379caf1", null ],
      [ "Least_squares_cylinder_fit_sorting_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#gaacf4c0b6f6e931b61e305c1a79cb06ff", null ],
      [ "make_least_squares_cylinder_fit_sorting", "group__PkgShapeDetectionRGOnPointSet3.html#ga2cea5715bdf24455232bc42a5780a90f", null ]
    ] ],
    [ "CGAL::Shape_detection::Point_set::Least_squares_line_fit_region< GeomTraits, Item_, PointMap, NormalMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__region.html", [
      [ "FT", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__region.html#a6fe98df0b40ef447123a3a721d019fe7", null ],
      [ "Item", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__region.html#aa49c1f9d59658e96018557aecfa159e5", null ],
      [ "Primitive", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__region.html#a1f237f78a17c9b5d324345789dfedcad", null ],
      [ "Region_unordered_map", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__region.html#aa7d400cc3c1c56a9b30fffc4bca376f8", null ],
      [ "Least_squares_line_fit_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__region.html#ae9ffb8b239a775cbd753b4196cac6b6e", null ],
      [ "is_part_of_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__region.html#a50ac91a9eb5b455ec8f029d92fd921f1", null ],
      [ "is_valid_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__region.html#ae3fe0c6d78a90893edf129f4b2dd0151", null ],
      [ "primitive", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__region.html#a2422cadc109c3fad425d28b9861744e8", null ],
      [ "region_index_map", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__region.html#a7b05ba1f7bffd22890d363ad53893cbf", null ],
      [ "update", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__region.html#af834e13072ea6fcd73806095e7e4e54e", null ],
      [ "Least_squares_line_fit_region_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#ga15880cd6f6afef2d3138d5c5c206151d", null ],
      [ "make_least_squares_line_fit_region", "group__PkgShapeDetectionRGOnPointSet3.html#ga5587563d9f9a7b3ce779bb8badd08e37", null ]
    ] ],
    [ "CGAL::Shape_detection::Point_set::Least_squares_line_fit_sorting< GeomTraits, Item_, NeighborQuery, PointMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__sorting.html", [
      [ "Item", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__sorting.html#a9d5c2cb721652b3b5376027ffb47fecd", null ],
      [ "Seed_range", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__sorting.html#a683ab2dd999a69ebeb0274e4a8cfdb20", null ],
      [ "Least_squares_line_fit_sorting", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__sorting.html#a4e1170bbaef77284507f69d62c57f11d", null ],
      [ "ordered", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__sorting.html#a5c3bfae93d8733144ccd59de688872e2", null ],
      [ "sort", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__line__fit__sorting.html#a2f5b1761d44622cdf1a67bace72d15d7", null ],
      [ "Least_squares_line_fit_sorting_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#ga137c6e7c3f30f0e78a5fe18063431bd6", null ],
      [ "make_least_squares_line_fit_sorting", "group__PkgShapeDetectionRGOnPointSet3.html#ga98815ab02c713ff0f3534b08510a7e5f", null ]
    ] ],
    [ "CGAL::Shape_detection::Point_set::Least_squares_plane_fit_region< GeomTraits, Item_, PointMap, NormalMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__region.html", [
      [ "FT", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__region.html#a1625a36306e1b3ce53ca05fd8123a660", null ],
      [ "Item", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__region.html#ab4b002a6ef64ef18460e052643b3acae", null ],
      [ "Primitive", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__region.html#a6436f172f9711523cf673b6a363821d5", null ],
      [ "Region_unordered_map", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__region.html#a74e195c01d35ca12a2742ffc3ef08e18", null ],
      [ "Least_squares_plane_fit_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__region.html#aebb7398fbb708fe0a68867a5af1e5652", null ],
      [ "is_part_of_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__region.html#a17138df35cc4d017eba222d7d0aaaeb7", null ],
      [ "is_valid_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__region.html#aefbd0ff0b011eef88f6314d17d03b1af", null ],
      [ "primitive", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__region.html#a5347917bcb2a429cf80862cd7d8e1758", null ],
      [ "region_index_map", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__region.html#a5de404fb4df52712327256f5086adf07", null ],
      [ "update", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__region.html#a040d28980725a221b92b8320cd04a9e4", null ],
      [ "Least_squares_plane_fit_region_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#ga16300a0ce273a2abc4f32848bd176aed", null ],
      [ "make_least_squares_plane_fit_region", "group__PkgShapeDetectionRGOnPointSet3.html#gac4c1c31e24bf462c6a302007fef90538", null ]
    ] ],
    [ "CGAL::Shape_detection::Point_set::Least_squares_plane_fit_sorting< GeomTraits, Item_, NeighborQuery, PointMap, NormalMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html", [
      [ "Item", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#a59236f525ca0a7b01ec2bd916adfc594", null ],
      [ "Seed_range", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#a1c57d994ccd1e376647c25bd589479c3", null ],
      [ "Least_squares_plane_fit_sorting", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#afcbf9046fd5ac3f351fa239982f10da1", null ],
      [ "mean_deviation", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#a9829c533f9c990717512cfe9612b50f8", null ],
      [ "mean_distance", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#aac029d1331c16876eea7769e43031232", null ],
      [ "ordered", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#a2a0076afad63cb8216efa9b1285994db", null ],
      [ "sort", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__plane__fit__sorting.html#a00884ad4be96fc5c0bdf54f6d0ebbdbd", null ],
      [ "Least_squares_plane_fit_sorting_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#gaa578dfccdbfca9625896790cfa0b19bd", null ],
      [ "make_least_squares_plane_fit_sorting", "group__PkgShapeDetectionRGOnPointSet3.html#ga2123a8a09f0799bd9083f25900e4cec9", null ]
    ] ],
    [ "CGAL::Shape_detection::Point_set::Least_squares_sphere_fit_region< GeomTraits, Item_, PointMap, NormalMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__region.html", [
      [ "FT", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__region.html#acb54e4bb2c1d3edc789a2967281f70c6", null ],
      [ "Item", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__region.html#a79ba4410d4f06f8b36a180738cded32f", null ],
      [ "Primitive", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__region.html#a3a57cbda892cdb44fe2ca103ac57b320", null ],
      [ "Region_unordered_map", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__region.html#acb7e05e0f1bc4bdbce6c62262ba7c7ae", null ],
      [ "Least_squares_sphere_fit_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__region.html#a4fb323efcbcdf9ef1751385c7bcb1abe", null ],
      [ "is_part_of_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__region.html#a52332a57f2178ab13d75ed91fef64af4", null ],
      [ "is_valid_region", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__region.html#a2670920ca0cdefcdf87962a226b2ebf2", null ],
      [ "primitive", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__region.html#a4d1fec7a983c7989a0a2b1b583d54660", null ],
      [ "region_index_map", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__region.html#abbf6c77127bc6589da679ac0ed65924a", null ],
      [ "update", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__region.html#a2cc61b32b6aa4f12b446cf52099e64d4", null ],
      [ "Least_squares_sphere_fit_region_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#ga529d9fbf05f76ca10b41a0f69d411695", null ],
      [ "make_least_squares_sphere_fit_region", "group__PkgShapeDetectionRGOnPointSet3.html#ga08dcd76b0147699dd6585eb71456990a", null ]
    ] ],
    [ "CGAL::Shape_detection::Point_set::Least_squares_sphere_fit_sorting< GeomTraits, Item_, NeighborQuery, PointMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__sorting.html", [
      [ "Item", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__sorting.html#a8323c19f21344c7e57f8a7e21c882f08", null ],
      [ "Seed_range", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__sorting.html#aee1278486ce09ad937b0d7a8f3b41b0a", null ],
      [ "Least_squares_sphere_fit_sorting", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__sorting.html#a7be04aaa7cce0bd4173ac951bb813ba6", null ],
      [ "ordered", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__sorting.html#a3d4b8ba177d954ddbd7cad8b9f6633b5", null ],
      [ "sort", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Least__squares__sphere__fit__sorting.html#a2085ca9185fd3bff002206d65611ae86", null ],
      [ "Least_squares_sphere_fit_sorting_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#ga93ea9c0b182180f349e1fb1dab08ac23", null ],
      [ "make_least_squares_sphere_fit_sorting", "group__PkgShapeDetectionRGOnPointSet3.html#gac73a2de603953300289dc3350331abd0", null ]
    ] ],
    [ "CGAL::Shape_detection::Point_set::Sphere_neighbor_query< GeomTraits, Item_, PointMap >", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Sphere__neighbor__query.html", [
      [ "FT", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Sphere__neighbor__query.html#acd0d49ba9839e65993b07e8232b3b39b", null ],
      [ "Sphere_neighbor_query", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Sphere__neighbor__query.html#afe18b83a2185f89e84e8f802bc0b5437", null ],
      [ "operator()", "classCGAL_1_1Shape__detection_1_1Point__set_1_1Sphere__neighbor__query.html#a99793a085dc0695dfd555570e365a4a4", null ],
      [ "make_sphere_neighbor_query", "group__PkgShapeDetectionRGOnPointSet3.html#gae19d6d2225dca432f7d720bdf4e1f99b", null ],
      [ "Sphere_neighbor_query_for_point_set", "group__PkgShapeDetectionRGOnPointSet3.html#ga755000675a1a44e35ea3a5731a4f0e02", null ]
    ] ]
];